@@ -1,4 +1,4 @@
-"""Refresh a dependent duplicate volume with a snapshot from its parent."""
+"""Refresh a duplicate volume with a snapshot from its parent."""
 # :license: MIT, see LICENSE for more details.
 
 import click
@@ -11,8 +11,8 @@ from SoftLayer.CLI import environment
 @click.argument('snapshot_id')
 @environment.pass_env
 def cli(env, volume_id, snapshot_id):
-    """"Refresh a dependent duplicate volume with a snapshot from its parent."""
+    """Refresh a duplicate volume with a snapshot from its parent."""
     block_manager = SoftLayer.BlockStorageManager(env.client)
-    resp = block_manager.refresh_dep_dupe(volume_id, snapshot_id)
+    resp = block_manager.refresh_dupe(volume_id, snapshot_id)
 
     click.echo(resp)
