@@ -56,6 +56,7 @@ DEFAULT_NOTES_SIZE = 20
 @click.command()
 @click.option('--username', '-u', help='Volume username')
 @click.option('--datacenter', '-d', help='Datacenter shortname')
+@click.option('--order', '-o', type=int, help='Filter by ID of the order that purchased the block storage')
 @click.option('--storage-type',
               help='Type of storage volume',
               type=click.Choice(['performance', 'endurance']))
@@ -66,12 +67,13 @@ DEFAULT_NOTES_SIZE = 20
                   ', '.join(column.name for column in COLUMNS)),
               default=','.join(DEFAULT_COLUMNS))
 @environment.pass_env
-def cli(env, sortby, columns, datacenter, username, storage_type):
+def cli(env, sortby, columns, datacenter, username, storage_type, order):
     """List file storage."""
     file_manager = SoftLayer.FileStorageManager(env.client)
     file_volumes = file_manager.list_file_volumes(datacenter=datacenter,
                                                   username=username,
                                                   storage_type=storage_type,
+                                                  order=order,
                                                   mask=columns.mask())
 
     table = formatting.Table(columns.columns)
